package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0D```````````(`/@`!````@'`@``````!``````````/"H````
M`````````$``.``+`$``'@`=``8````$````0`````````!``"```````$``
M(```````:`(```````!H`@````````@``````````P````0```"H`@``````
M`*@"(```````J`(@```````5`````````!4``````````0`````````!````
M!``````````````````@`````````"```````'Q@````````?&``````````
M$`````````$````%````@&````````"`<"```````(!P(```````D$(`````
M``"00@`````````0`````````0````8````0HP```````!##(```````$,,@
M```````8`@```````/`,`````````!`````````!````!@```"BE````````
M*-4@```````HU2```````!@"````````D0(`````````$`````````(````&
M````0*,```````!`PR```````$##(```````X`$```````#@`0````````@`
M````````4N5T9`0````0HP```````!##(```````$,,@```````8`@``````
M`/`,`````````0````````!0Y71D!````$A;````````2%L@``````!(6R``
M`````-P`````````W``````````$`````````%'E=&0&````````````````
M````````````````````````````````````````````````````!`````0`
M``#``@```````,`"(```````P`(@``````!(`````````$@`````````!```
M```````O;&EB97AE8R]L9"UE;&8N<V\N,0`````(````!`````$```!&<F5E
M0E-$`)YB%0`(````!`````0```!&<F5E0E-$```````(````!`````(```!&
M<F5E0E-$```````````````````````````````````````-````$@``````
M```````````````````Z````(`````````````````````````!6````%@``
M``````````````````````!Y````$@````````````````````````"L````
M$@````````````````````````"S````$@````````````````````````"[
M````$@````````````````````````#$````$@``````````````````````
M``#+````$@````````````````````````#2````$@``````````````````
M```````!`0``$@`````````````````````````)`0``$@``````````````
M```````````0`0``$@`````````````````````````7`0``$@``````````
M```````````````>`0``$@`````````````````````````E`0``$@``````
M```````````````````L`0``$@`````````````````````````Q`0``$@``
M```````````````````````X`0``$@````````````````````````!``0``
M$@````````````````````````!5`0``$@````````````````````````!I
M`0``$@````````````````````````"=`0``$@``````````````````````
M``"F`0``$@````````````````````````#&`0``$@``````````````````
M``````#-`0``$@````````````````````````#U`0``$@``````````````
M``````````#[`0``$@`````````````````````````!`@``$@``````````
M```````````````)`@``$@`````````````````````````1`@``$@``````
M```````````````````6`@``$@`````````````````````````<`@``$@``
M```````````````````````A`@``$@`````````````````````````R`@``
M$@`````````````````````````Z`@``$@````````````````````````!"
M`@``$@````````````````````````!)`@``$@``````````````````````
M``!2`@``$@````````````````````````!N`@``$@``````````````````
M``````!^`@``$@````````````````````````",`@``$@``````````````
M``````````"3`@``$@````````````````````````"B`@``$@``````````
M``````````````"N`@``$@````````````````````````"Z`@``$@``````
M``````````````````#/`@``$@`````````````````````````"`P``$@``
M```````````````````````>`P``$@`````````````````````````I`P``
M$@`````````````````````````X`P``$@````````````````````````!5
M`P``$@````````````````````````!@`P``$@``````````````````````
M``!I`P``$@````````````````````````!W`P``$@``````````````````
M``````"!`P``$@````````````````````````"/`P``$@``````````````
M``````````"^`P``$@````````````````````````!.````$@`.`"!Q(```
M````+0````````!I````$@```'"O(`````````````````":````$0`;`'#7
M(```````0`````````#H`0``$@`.`/"$(```````+@H```````"I`P``$@`.
M`-"9(```````_0`````````T````$@`0`"BO(``````````````````(````
M$@`.`'"5(```````H@,```````#C````$@`.`!!R(```````L@````````#T
M````$@`.`-!R(```````.P(```````!P`0``$@`.`'!X(```````&@H`````
M``"K`0``$@`.`."#(```````'@````````#6`0``$@`.``"$(```````Z```
M``````#>`@``$@```$"R(`````````````````#O`@``$@```%"R(```````
M```````````1`P``$0`;`+C7(````````0`````````!````$@`.`(!P(```
M````,0````````"$````$@`.`%!Q(```````L@````````!=`0``$@`.`'!W
M(```````\@````````!]`0``$@`.`)""(```````JP````````"3`0``$0`;
M`+#7(```````"``````````F`@``$@`.`""/(```````]0````````!+`P``
M$0`9`##5(```````"`````````"@`P``$@`.`("9(```````3`````````"T
M`P``$@`.`("M(```````9P$````````N````$@`/`!RO(```````````````
M``!(`0``$@`.`$!W(```````*0````````!8`@``$@`.`*"1(```````P0,`
M```````;````$0`9`"C5(```````"``````````F````$0`;`$#7(```````
M"`````````"+`0``$@`.`$"#(```````F0````````````(``0`!``$``P`#
M``,``P`#``,``P`#``,``P`#``,`!``#``,``P`#``,``P`#``,``P`$``,`
M`P`#``,``P`#``,``P`$``,``P`#``$``0`#``$``0`!``$``0`%``$``0`!
M``$``0`!``$``0`!``,``0`!``,``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`#``$``0`!``$``0`!``$``0`!``$````!``$`Q0,``"`````0
M`````0`#`-H#```@`````````+`H>@<```4`T0,```````"P*'H'```#`-$#
M```0````M2AZ!P``!`#D`P``$````+<H>@<```(`[0,`````````````!P``
M`#L````(````&@````((,``!``P("``0!`($``@```0`B```$`"($(``````
M"`````%@``"```""P(0`@$@!``Y!`!0!#0H`$8L$``@[````/````$````!!
M````2@```%,```!6````P^4_+'KP2FL@8F0'SMY'+4/ZUX?KT^\.:G^:?"[%
MF[8@_^0.HN#[27ZIG)OZH6Q@AOF<@<C5LG$+BA!7,F+;[>"G`@IFK\QFL@&+
M;^85`X-NQ=\?B`=PTQ2,)<QK&IY0N(WQ#N)'Q@'59-1\O%!VGJ;=HVN93\.;
M60```%D````9````3@````````!6````'P```"4````Z````2`````````!3
M````0@```````````````````````````````````%```````````````%$`
M```R````/0```$\````\````2@```$<````K`````````!(```!4````)@``
M``L````I````/P```!P`````````'0```$``````````&@````\`````````
M30```"(````V````-P```"T```!8`````````%<```!!````3````"\````3
M````&````"P````A`````````#$````N`````````!X`````````-```````
M``!2```````````````^``````````,`````````&P```#@`````````1@``
M````````````$````$L`````````,P```#D```!$````20``````````````
M50````````````````````````````````````````````````````@`````
M````````````````````````````````````````````````````$0``````
M````````%`````4```````````````H`````````````````````````````
M```````5```````````````````````````````.```````````````D````
M``````$````````````````````H````)P``````````````!P``````````
M`````````#4`````````(``````````"````#0```````````````````",`
M```[````!`````8`````````0P````D````````````````````,````,```
M``````````````````````!%````%@`````````7`````````"H`````````
M`%]S=&%R=`!M86EN`%]?;&EB8U]S=&%R=#$`7U]P<F]G;F%M90!E;G9I<F]N
M`%]I;FET`%]F:6YI`%]*=E]296=I<W1E<D-L87-S97,`>'-?:6YI=`!03%]C
M=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R`%!E<FQ?;F5W6%,`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`%]?<W1A8VM?8VAK7V=U87)D`&=E='!I9`!S
M<')I;G1F`')E861L:6YK`&UA;&QO8P!M96UC<'D`7U]S=&%C:U]C:&M?9F%I
M;`!P87)?8W5R<F5N=%]E>&5C`'!A<E]F:6YD<')O9P!S=')N8VUP`'-T<F-H
M<@!S=')D=7``<W1R=&]K`'-T<F-M<`!S=')L96X`<W1A=`!A8V-E<W,`<F5A
M;&QO8P!M96UM;W9E`'!A<E]B87-E;F%M90!S=')R8VAR`'!A<E]D:7)N86UE
M`'-T<F-P>0!P87)?:6YI=%]E;G8`<&%R7V5N=E]C;&5A;@!P87)?9&EE`%]?
M<W1D97)R<`!V9G!R:6YT9@!E>&ET`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W
M=6ED`&=E='5I9`!G971P=W5I9`!P87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT
M;7!D:7(`;'-T870`;6MD:7(`7U]E<G)O<@!F<')I;G1F`&]P96X`;'-E96L`
M<F5A9`!F<F5E`'!A<E]C;&5A;G5P`&]P96YD:7(`<F5A9&1I<@!U;FQI;FL`
M8VQO<V5D:7(`<FUD:7(`6%-?26YT97)N86QS7U!!4E]"3T]4`%!E<FQ?9W9?
M9F5T8VAP=@!097)L7W-V7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!0
M97)L7V=E=%]S=@!097)L7VUG7W-E=`!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`%!E<FQ?871F;W)K7W5N
M;&]C:P!P=&AR96%D7V%T9F]R:P!03%]D;U]U;F1U;7``<&5R;%]A;&QO8P!P
M97)L7V-O;G-T<G5C=`!097)L7W-A9F5S>7-M86QL;V,`;7E?<&%R7W!L`'!E
M<FQ?<&%R<V4`<&5R;%]R=6X`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R
M;%]S>7-?=&5R;0!097)L7VYE=UA37V9L86=S`'-H85]I;FET`'-H85]U<&1A
M=&4`<VAA7V9I;F%L`&UE;7-E=`!L:6)T:'(N<V\N,P!&0E-$7S$N,`!L:6)C
M+G-O+C<`1D)31%\Q+C4`1D)31%\Q+C<`+W5S<B]L;V-A;"]L:6(O<&5R;#4O
M-2XS-B]M86-H+T-/4D4`;&EB<&5R;"YS;RXU+C,V`&QI8F1L+G-O+C$`;&EB
M;2YS;RXU`&QI8F-R>7!T+G-O+C4`;&EB=71I;"YS;RXY````(,4@```````2
M`````P``````````````<-<@```````%````/0``````````````N-<@````
M```%````20``````````````L-<@```````%````3@``````````````8-4@
M```````'`````0``````````````:-4@```````'`````@``````````````
M<-4@```````'````/```````````````>-4@```````'````!```````````
M````@-4@```````'````!0``````````````B-4@```````'````!@``````
M````````D-4@```````'````!P``````````````F-4@```````'````"```
M````````````H-4@```````'````"0``````````````J-4@```````'````
M"@``````````````L-4@```````'````"P``````````````N-4@```````'
M````#```````````````P-4@```````'````#0``````````````R-4@````
M```'````#@``````````````T-4@```````'````#P``````````````V-4@
M```````'````$```````````````X-4@```````'````$0``````````````
MZ-4@```````'````$@``````````````\-4@```````'````$P``````````
M````^-4@```````'````%````````````````-8@```````'````%0``````
M````````"-8@```````'````%@``````````````$-8@```````'````%P``
M````````````&-8@```````'````&```````````````(-8@```````'````
M&0``````````````*-8@```````'````&@``````````````,-8@```````'
M````&P``````````````.-8@```````'````'```````````````0-8@````
M```'````'0``````````````2-8@```````'````'@``````````````4-8@
M```````'````'P``````````````6-8@```````'````(```````````````
M8-8@```````'````(0``````````````:-8@```````'````(@``````````
M````<-8@```````'````(P``````````````>-8@```````'````)```````
M````````@-8@```````'````)0``````````````B-8@```````'````)@``
M````````````D-8@```````'````)P``````````````F-8@```````'````
M*```````````````H-8@```````'````*0``````````````J-8@```````'
M````*@``````````````L-8@```````'````*P``````````````N-8@````
M```'````+```````````````P-8@```````'````+0``````````````R-8@
M```````'````+@``````````````T-8@```````'````+P``````````````
MV-8@```````'````1P``````````````X-8@```````'````2```````````
M````Z-8@```````'````,```````````````\-8@```````'````,0``````
M````````^-8@```````'````,@```````````````-<@```````'````,P``
M````````````"-<@```````'````-```````````````$-<@```````'````
M-0``````````````&-<@```````'````-@``````````````(-<@```````'
M````-P``````````````*-<@```````'````.```````````````,-<@````
M```'````.0``````````````.-<@```````'````.@``````````````````
M```````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"5S+R5S`$EN=&5R;F%L<SHZ4$%2
M.CI"3T]4`%1-4`!005)?5$5-4`!005)?0T%#2$4`4UE35$5-`"\``"X`+W!R
M;V,O)6DO)7,`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`4$523$E/
M`'!E<FP`4$523#5/4%0`&`!005)?1TQ/0D%,7T-,14%.`%1-4$1)4@!0051(
M`"XN`#$N,#8S`%!!4E]#3$5!3@!P87)L`"YP87(`)7,E<W1E;7`M)74E<P`Z
M`#$`4$%27U1-4$1)4@`E<R5S=&5M<"TE=2TE=25S`'!A<BT`<VAO<G0@<F5A
M9``M90!005)?24Y)5$E!3$E:140`+W1M<"\`)7,E<R5S)7,`4$%2.CI086-K
M97(Z.E9%4E-)3TX`+2T`,``O<')O8R]C=7)P<F]C+V9I;&4`4$%27U!23T=.
M04U%`%!!4E]$14)51P!54T52`"5S)7,E<P!005)?1TQ/0D%,7T1%0E5'`%1%
M35!$25(`;'-E96L@9F%I;&5D`')E860@9F%I;&5D`%!!4E]34$%73D5$`%!!
M4E]'3$]"04Q?5$5-4`!414U0`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O
M;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&
M24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD
M4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`]
M(#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:
M25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC
M"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE
M+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D
M<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@
M/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C
M:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@
M<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S
M("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*
M;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A
M8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE
M(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO
M<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F
M:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T
M<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L
M96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0[
M"F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!
M4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@
M+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L
M:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I
M+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D
M<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM0
M05)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S
M+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)
M1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A
M=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE
M("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E
M<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*
M;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O
M=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H
M(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!
M3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'
M24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E
M96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E
M860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]
M('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O
M9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,
M15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@
M7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A
M9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR
M96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L
M("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN
M9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D
M8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN
M*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@
M+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E
M7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO
M9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@
M)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A
M8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R
M+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I
M;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2([
M"B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F
M:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F
M?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE
M;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N
M92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@
M1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)
M0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@
M("`@("`C('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L
M("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM0
M05)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C
M=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R
M(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@
M)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A
M<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@
M-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B
M=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D
M;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE
M.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&
M2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@
M+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D
M,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E
M<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]
M(&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G
M*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD
M7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\
M+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE
M<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V
M86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB
M7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W
M<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO
M;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#
M86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T
M.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO
M=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF
M("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@
M)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N
M=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I
M<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D
M14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L
M*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L
M"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O
M)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N
M86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U
M="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF
M("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@
M<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F
M:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C
M86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS
M965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@
M,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I
M>F4["B1C86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L
M"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T
M:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B10
M05)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X
M:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?
M<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C
M:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O
M;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I
M(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP
M.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ
M6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF
M;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M
M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U[
M"EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH
M6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?
M;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E
M>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M
M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG
M("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D
M9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M
M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M
M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#
M86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5
M<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=
M(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O
M=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM
M>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D
M8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE
M<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&
M:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@
M;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@
M>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN
M=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U
M:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M
M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&
M:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I
M<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@
M0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E
M(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII
M<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A
M<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)
M3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E
M=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D
M14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E
M='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H
M(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#
M.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T
M:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY
M("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F
M:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@
M>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F
M:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R
M+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P
M-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C
M86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B
M/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G
M;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G
M:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%
M7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68[
M"G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?
M;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE
M7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*
M?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@
M+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W
M)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L
M;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z
M("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E
M.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M
M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@[
M"GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@
M+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT
M(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!
M4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R
M;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5]
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y
M<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D
M<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D
M7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*
M)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI
M<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`4$52
M3$Q)0@!,1%],24)205)97U!!5$@`55-%4DY!344`)7,Z('!R:79A=&4@<W5B
M9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@
M<F5T<GD@>6]U<B!O<&5R871I;VXI"@`E<R5S8V%C:&4M)7,E<P!F:6QE`%!%
M4DPU3$E"`%!!4E]'3$]"04Q?5$U01$E2`"4P,G@``"XO<&5R;'AS:2YC````
M``#V&R```````+L;(```````I1P@``````#B'"```````.P:(```````````
M````````0T%#2$4```$;`SO<````&@```#@5``#X````>!4``!@!``"H%0``
M.`$``-@5``!@`0``"!8``(`!``#(%@``J`$``(@7``#0`0``R!D````"``#X
M&P``,`(``"@<``!0`@``*!T``(`"``!()P``L`(``/@G``#8`@``F"@``/0"
M``"X*```'`,``*@I``!$`P``V#,``'P#``#8-```K`,``%@V``#D`P``*#H`
M`!0$``#8/0``1`0``#@^``!H!```B#X``(@$``"(/P``M`0``#A2``#D!```
MJ%,``!`%````````%``````````!>E(``7@0`1L,!PB0`0``'````!P````X
M%```,0`````'$$$."$.&`@T&```````<````/````%@4```L`````$$.$(8"
M0PT&0H,#90P'""0```!<````:!0``"4`````00X0A@)##09:#`<(10P&$$$,
M!P@````<````A````'`4```M`````$$.$(8"0PT&9`P'"````"0```"D````
M@!0``+(`````00X0A@)##09*@P2.`P*>#`<(00P&$``D````S````!@5``"R
M`````$$.$(8"0PT&2H,$C@,"G@P'"$$,!A``+````/0```"P%0``.P(```!!
M#A"&`D,-!E"#!XP&C06.!(\#`O`,!PA!#`80````+````"0!``#`%P``,`(`
M``!!#A"&`D,-!DV#!XP&C06.!(\#`_T!#`<(00P&$```'````%0!``#`&0``
M*0````!!#A"&`D,-!D*#`UX,!P@L````=`$``-`9``#R`````$$.$(8"0PT&
M2H,$C@,"4PP'"$4,!A`"A@P'"$$,!A`L````I`$``*`:```:"@```%$.$(8"
M0PT&2H,'C`:-!8X$CP,#[0D,!PC#S,W.S\8D````U`$``)`D``"K`````$$.
M$(8"0PT&1H,%C@2/`P*@#`<(````&````/P!```8)0``F0````!!#A"&`D,-
M!@```"0````8`@``G"4``!X`````00X0A@)##095#`<(00P&$$,,!P@````D
M````0`(``)0E``#H`````$$.$(8"0PT&1X,&C`6.!(\#`M@,!P@`-````&@"
M``!<)@``+@H```!!#A"&`D,-!E"#!XP&C06.!(\#`L\,!PA%#`80`WP$#`<(
M00P&$``L````H`(``%0P``#U`````$$.$(8"0PT&1X,&C`6.!(\#`MP,!PA!
M#`802PP'"``T````T`(``"0Q``!]`0```$$.$(8"0PT&4(,'C`:-!8X$CP,#
M-0$,!PA!#`80:0P'"$4,!A```"P````(`P``;#(``,$#````00X0A@)##090
M@P>,!HT%C@2/`P-N`PP'"$$,!A```"P````X`P``##8``*(#````00X0A@)#
M#09-@P>,!HT%C@2/`P.!`PP'"$$,!A```"````!H`P``C#D``%0`````00X0
MA@)##09#@P2.`P)(#`<(`!P```",`P``R#D``$P`````00X0A@)##08"1PP'
M"```*````*P#``#X.0``_0````!!#A"&`D,-!DJ#!XP&C06.!(\#`NX,!P@`
M```L````V`,``,PZ``"A$@```$$.$(8"0PT&4(,'C`:-!8X$CP,#AQ(,!PA!
M#`80```H````"`0``$Q-``!G`0```$$.$(8"0PT&2H,'C`:-!8X$CP,#5`$,
M!P@``!P````T!```D$X``"P`````00X0A@)##09"@P-E#`<(``````````!5
M2(GE2(GQ2(G^2(/&"$B)^DB#PA!(8P>)QTC!X`-(`<))N'"5(```````Z*`^
M``#,S,S,S,S,S,S,S,S,S,S,54B)Y5-0NRC#(``/'T0``$B+`TB-2`%(@_D"
M<@C_T$B#PPCKZTB#Q`A;7<,/'T``54B)Y;@`````2(7`=!5(@STJ4@```'0+
MOS##(`!=Z4T^``!=P\S,S,S,S,S,S,S,54B)Y4B+!?53``!D2(L,)0````!(
MBSP!OCP;(`"Z<*\@`+D`6R``7>DS/@``#Q\`54B)Y4%64TB!["`(``!(BP4+
M9@``2(E%Z.@B/@``,=M(C;W@^___O@\;(`"YVEH@`(G",<#H%CX``(7`>%-(
MC;W@^___2(VUT/?__[H`!```Z`H^``!)B<9%A?9X,4&-?@'H"3X``$B%P'0C
M2(G#08'F____?TB-M=#W__](B<=,B?+H^#T``$+&!#,`ZP(QVTB+!8AE``!(
M.T7H=0](B=A(@<0@"```6T%>7</HWCT``&9F9F9F+@\?A```````54B)Y4%6
M4TB!["`(``!(BP5+90``2(E%Z.AB/0``,=M(C;W@^___O@\;(`"YVEH@`(G"
M,<#H5CT``(7`>%-(C;W@^___2(VUT/?__[H`!```Z$H]``!)B<9%A?9X,4&-
M?@'H23T``$B%P'0C2(G#08'F____?TB-M=#W__](B<=,B?+H.#T``$+&!#,`
MZP(QVTB+!<AD``!(.T7H=0](B=A(@<0@"```6T%>7</H'CT``&9F9F9F+@\?
MA```````54B)Y4%7059!54%44TB![/@$``!)B?1(B?M(BP5_9```2(E%T$R+
M/41D``!-A?\/A'P```!,B:7H^O__N/`:(`!%,>1(N0`````!````9I`/MA"%
MTG0-@_H]=`A(_\!)`<SK[$V++TV%[71*2<'\($F#QPA%,?;K$P\?@`````!-
MBR])@\<(387M="V^\!H@`$R)[TR)XNB$/```A<!UX$.`?"4`/7783XTT+$G_
MQNL(13'VZPI%,?9,BZ7H^O__2(G?OB\```#H8SP``$B%P'0SOW$<(`!(B=[H
M80$``$B+!;IC``!(.T70#X5&`0``2(G82('$^`0``%M!7$%=05Y!7UW#3(GG
MZ#,\``"^\AL@`$B)Q^@V/```2(7`=+-)B<5,C;W0^___ZQD/'T0``+[R&R``
M,?_H%#P``$F)Q4B%P'2.08!]``"X#1L@`$P/1.A-A?9T#TR)]TR)[NC^.P``
MA<!TRDR)[^@"/```3`'H2/_(23G%<Q</'X``````@#@O=0O&``!(_\A).<5R
M\$R)[^C8.P``28G$2(G?Z,T[``!,`>!(_\!(/0`$```/@QW___^^C1P@`+D*
M&R``3(G_3(GJ28G8,<#H`3L``$R)_TB-M?#Z___HHCL``(7`#X5*____#[>%
M"/O__R4`\```/0"````/A3/___],B?^^`0```.B&.P``A<`/A1[___](C9W0
M^___OW$<(`!(B=[H&@```$B)W^@2.P``2(G#Z:G^___HU3H```\?1```54B)
MY4%7059!54%44TB#[!A)B?XQVX`^/0^4PT@!\TB)W^@).P``3(LE`F(``$V%
M]DR)==!(B5W`2(E%R'0W387D=#),B?9%,>U%,?9(N0`````!````9@\?A```
M````0@^V%#:%TG0E@_H]="!)_\9)`<WKZDF#/"0`='HQVY!)@WS<"`!(C5L!
M=?3K:TV+/"1-A?]T8$G!_2`QV^L2D$V+?-P(2/_#387_2(MUT'3,3(G_3(GJ
MZ"0Z``"%P'7@0X`\+SUUV4N-/"](_\?H73H``$B+?<A(.?@/@R\!``!,BWW`
M2(M-T$B^``````$```#ICP```#';@#U880```4R+?<!U*$&)WDJ--/40````
M3(GGZ$<Z``!(B04080``2(7`#X37````28G$ZSW&!2-A```!08G>2HT\]1``
M``#H:SD``$B%P`^$L@```$J-%/4`````2(G'3(GF28G$Z`PZ``!,B27%8```
M2+X``````0```$B+?<A+QT3T"`````!(BTW0,<`/'X0```````^V$872=`V#
M^CUT"$C_P4@!\.OL2,'X($@!QTB#QP+H_#@``$ACRTF)!,Q(A<!T0$B+!6E@
M``!(BP3(2(M5T)`/M@J("(7)=`V#^3UT"$C_PDC_P.OJQ@`]N0$```!FD$$/
MME0/_X@4"$C_P832=?!(@\086T%<05U!7D%?7<-)8\9,`?A(_\`QR4B+=<!F
MD`^V%`Z(%`A(_\&$TG7RZ]!52(GE4U!(B?N^+P```.@].0``2(UX`4B%P$@/
M1/M(@\0(6UWIIS@```\?@`````!52(GE05932('L$`0``$B+!>M?``!(B47H
M2(7_="*`/P!T'4F)_NBE.```2`4`_/__2#W_^___<RTQP.F4````2(L%N5\`
M`$@[1>@/A9P```"_#1L@`$B!Q!`$``!;05Y=Z3HX``!(C9W@^___2(G?3(GV
MZ+@X``!(B=_H4#@``$@!Z$@%W_O__T@YV'829I"`."]U"\8``$C_R$@YV'?P
M2(V=X/O__TB)W[XO````Z&PX``!(A<!T$4@YV'8#Q@``2(V]X/O__^L%OPT;
M(`#HS#<``$B+#25?``!(.TWH=0Q(@<00!```6T%>7</H?C<``&9F9F9F+@\?
MA```````2(L5R5X``$B%T@^$^PD``%5(B>5!5T%6055!5%-02;T``````0``
M`#';N-]:(`"0#[8(A<ET&8/Y/7042/_`3`'KZ^QF9F8N#Q^$``````!,BS)-
MA?8/A'T```!(P?L@2(E5T$R-8@A%,?_K$P\?`$V+-"1-`>])@\0(387V=%6^
MWUH@`$R)]TB)VNCP-@``A<!UW$&`/!X]==5)P?\@2(M%T$J-!/A(@\`(#Q]$
M``!(BPA(B4CX2(/`"$B%R77P2(L5"5X``$B%T@^%6/___^DH"0``2(M5T+A7
M6B``,=L/M@B%R709@_D]=!1(_\!,`>OK[&9F9BX/'X0``````$R+,DV%]@^$
M?0```$C!^R!(B5703(UB"$4Q_^L3#Q\`38LT)$T![TF#Q`A-A?9T5;Y76B``
M3(GW2(G:Z$`V``"%P'7<08`\'CUUU4G!_R!(BT702HT$^$B#P`@/'T0``$B+
M"$B)2/A(@\`(2(7)=?!(BQ5970``2(72#X59____Z7@(``!(BU70N)\;(``Q
MVP^V"(7)=!F#^3UT%$C_P$P!Z^OL9F9F+@\?A```````3(LR387V#X1]````
M2,'[($B)5=!,C6((13'_ZQ,/'P!-BS0D30'O28/$"$V%]G15OI\;(`!,B?=(
MB=KHD#4``(7`==Q!@#P>/7752<'_($B+1=!*C03X2(/`"`\?1```2(L(2(E(
M^$B#P`A(A<EU\$B+%:E<``!(A=(/A5G____IR`<``$B+5="XDQL@`#';#[8(
MA<ET&8/Y/7042/_`3`'KZ^QF9F8N#Q^$``````!,BS)-A?8/A'T```!(P?L@
M2(E5T$R-8@A%,?_K$P\?`$V+-"1-`>])@\0(387V=%6^DQL@`$R)]TB)VNC@
M-```A<!UW$&`/!X]==5)P?\@2(M%T$J-!/A(@\`(#Q]$``!(BPA(B4CX2(/`
M"$B%R77P2(L5^5L``$B%T@^%6?___^D8!P``2(M5T+@E'"``,=L/M@B%R709
M@_D]=!1(_\!,`>OK[&9F9BX/'X0``````$R+,DV%]@^$?0```$C!^R!(B570
M3(UB"$4Q_^L3#Q\`38LT)$T![TF#Q`A-A?9T5;XE'"``3(GW2(G:Z#`T``"%
MP'7<08`\'CUUU4G!_R!(BT702HT$^$B#P`@/'T0``$B+"$B)2/A(@\`(2(7)
M=?!(BQ5)6P``2(72#X59____Z6@&``!(BU70N,8<(``QVP^V"(7)=!F#^3UT
M%$C_P$P!Z^OL9F9F+@\?A```````3(LR387V#X1]````2,'[($B)5=!,C6((
M13'_ZQ,/'P!-BS0D30'O28/$"$V%]G15OL8<(`!,B?=(B=KH@#,``(7`==Q!
M@#P>/7752<'_($B+1=!*C03X2(/`"`\?1```2(L(2(E(^$B#P`A(A<EU\$B+
M%9E:``!(A=(/A5G____IN`4``$B+5="X\!H@`#';#[8(A<ET&8/Y/7042/_`
M3`'KZ^QF9F8N#Q^$``````!,BS)-A?8/A'T```!(P?L@2(E5T$R-8@A%,?_K
M$P\?`$V+-"1-`>])@\0(387V=%6^\!H@`$R)]TB)VNC0,@``A<!UW$&`/!X]
M==5)P?\@2(M%T$J-!/A(@\`(#Q]$``!(BPA(B4CX2(/`"$B%R77P2(L5Z5D`
M`$B%T@^%6?___^D(!0``2(M5T+C0&R``,=L/M@B%R709@_D]=!1(_\!,`>OK
M[&9F9BX/'X0``````$R+,DV%]@^$?0```$C!^R!(B5703(UB"$4Q_^L3#Q\`
M38LT)$T![TF#Q`A-A?9T5;[0&R``3(GW2(G:Z"`R``"%P'7<08`\'CUUU4G!
M_R!(BT702HT$^$B#P`@/'T0``$B+"$B)2/A(@\`(2(7)=?!(BQ4Y60``2(72
M#X59____Z5@$``!(BU70N'X<(``QVP^V"(7)=!F#^3UT%$C_P$P!Z^OL9F9F
M+@\?A```````3(LR387V#X1]````2,'[($B)5=!,C6((13'_ZQ,/'P!-BS0D
M30'O28/$"$V%]G15OGX<(`!,B?=(B=KH<#$``(7`==Q!@#P>/7752<'_($B+
M1=!*C03X2(/`"`\?1```2(L(2(E(^$B#P`A(A<EU\$B+%8E8``!(A=(/A5G_
M___IJ`,``$B+5="X^1H@`#';#[8(A<ET&8/Y/7042/_`3`'KZ^QF9F8N#Q^$
M``````!,BS)-A?8/A'T```!(P?L@2(E5T$R-8@A%,?_K$P\?`$V+-"1-`>])
M@\0(387V=%6^^1H@`$R)]TB)VNC`,```A<!UW$&`/!X]==5)P?\@2(M%T$J-
M!/A(@\`(#Q]$``!(BPA(B4CX2(/`"$B%R77P2(L5V5<``$B%T@^%6?___^GX
M`@``2(M5T+AQ'"``13'V9F9F9F9F+@\?A```````#[8(A<ET&8/Y/7042/_`
M30'NZ^QF9F8N#Q^$``````!(B5702(L:2(7;#X2?````2<'^($B+1=!,C6`(
M13'M28G?ZR9F9F8N#Q^$``````!-BSPD2+@``````0```$D!Q4F#Q`A-A?]T
M9;YQ'"``3(G_3(GRZ.8O``"%P'720X`\-SUURTG!_2!(BT702HT$Z$B#P`AF
M9BX/'X0``````$B+"$B)2/A(@\`(2(7)=?!(BQ7Y5@``2(722;T``````0``
M``^%'____^D.`@``N)0<(`!%,?9)O0`````!````3(MET&9F+@\?A```````
M#[8(A<ET#8/Y/70(2/_`30'NZ^Q(A=MT5DG!_B!-C7PD".L89F9F+@\?A```
M````28L?28/'"$B%VW0SOI0<(`!(B=],B?+H)"\``(7`=>!"@#PS/7792HTT
M,TC_QK]^'"``Z"CT__],BR515@``387D#X1U`0``N.A:(``QVY`/M@B%R70-
M@_D]=`A(_\!,`>OK[$V+-"1-A?9T6TC!^R!-C7PD".L4#Q^$``````!-BS=)
M@\<(387V=#.^Z%H@`$R)]TB)VNBD+@``A<!UX$&`/!X]==E)C30>2/_&O_8;
M(`#HJ//__TR+)=%5``!-A>0/A/4```"XTAP@`$4Q]@^V"(7)=`V#^3UT"$C_
MP$T![NOL3(EET$F+'"1(A=MT44G!_B!(BT703(U@"$F)W^L;9F9F9F8N#Q^$
M``````!-BSPD28/$"$V%_W0EOM(<(`!,B?],B?+H$RX``(7`==]#@#PW/778
M30'WO_`:(`#K<+BJ&R``13'V3(M]T&:0#[8(A<ET#8/Y/70(2/_`30'NZ^Q(
MA=MT5$G!_B!)@\<(ZQEF9F9F+@\?A```````28L?28/'"$B%VW0QOJH;(`!(
MB=],B?+HI"T``(7`=>!"@#PS/7793`'SO]`;(`!)B=])_\=,B?[HH_+__TB#
MQ`A;05Q!74%>05]=OR4<(`"^]!L@`.F&\O__9@\?1```54B)Y4%705934$R+
M/9]4``!-A?\/A(0```"XT!L@`#';2+D``````0````\?1```#[80A=)T#8/Z
M/70(2/_`2`'+Z^Q-BS<QP$V%]G122,'[($F#QPCK%`\?A```````38LW28/'
M"$V%]G0ROM`;(`!,B?=(B=KHY"P``(7`=>!!@#P>/77900^V1!X!A,`/E<$\
M,`^5P"#(#[;`ZP(QP$B#Q`A;05Y!7UW##Q]$``!52(GE2('LT````$F)^DB)
MM3C___](B95`____2(F-2/___TR)A5#___],B8U8____A,!T)@\IA6#___\/
M*8UP____#RE5@`\I79`/*66@#REML`\I=<`/*7W02(V%,/___TB)1?!(C440
M2(E%Z$BX"````#````!(B47@2(L][5,``$B-5>!,B=;HX2P``+__````Z.<L
M```/'X``````54B)Y>CG+```B<?H\"P``$B%P'0%2(L`7<,QP%W#9I!52(GE
M05=!5D%44TB)^TR+)2M3``!-A>0/A+4```"X7UH@`$4Q]DBY``````$````/
MMA"%TG0-@_H]=`A(_\!)`<[K[$V+/"1-A?\/A((```!)P?X@28/$".L2#Q]$
M``!-BSPD28/$"$V%_W1FOE]:(`!,B?],B?+H<RL``(7`==]#@#PW/77830'^
M2?_&3(GWZ*HK``!(A<!T.$F)QTB)W^B:*P``28T\!TB#QP+H#2L``$F)Q[Z-
M'"``N?(;(`!(B<=(B=I-B?`QP.C0*@``3(G[OU]:(`!(B=Y;05Q!7D%?7>DH
M\/__#Q^$``````!52(GE05=!5D%505132('L.``!`$F)_$B+!6)2``!(B470
M2(L=)U(``$B%VP^$M@```+CP&B``13'V2+H``````0```&9F9BX/'X0`````
M``^V"(7)=`V#^3UT"$C_P$D!UNOL3(L[387_='Q)P?X@2(/#".L69BX/'X0`
M`````$R+.TB#PPA-A?]T7+[P&B``3(G_3(GRZ&0J``"%P'7@0X`\-SUUV4.`
M?#<!`'0Y2XT<-TC_PTB)W^A2_O__2(L%NU$``$@[1=`/A38)``!(B=](@<0X
M``$`6T%<05U!7D%?7>DX*@``3(FEL/_^_^CL*@``B<?H]2H``$B%P'0,2(L`
M2(7`#X4F`0``2(L=/5$``$B%VP^$%`$``+B('"``13'V2+H``````0```&:0
M#[8(A<ET#8/Y/70(2/_`20'6Z^Q,BSM-A?]T8DG!_B!,C6,(ZQ=F+@\?A```
M````38L\)$F#Q`A-A?]T.+Z('"``3(G_3(GRZ(,I``"%P'7?0X`\-SUUV$.`
M?#<!`'052XT\-TC_Q^B$*0``2(7`#X6-````2(7;#X2"````N&]:(`!%,?9(
MN@`````!````#[8(@_D]=`R%R70(2/_`20'6Z^Q,BSM-A?]T5$G!_B!(@\,(
MZQ9F+@\?A```````3(L[2(/#"$V%_W0TOF]:(`!,B?],B?+H]"@``(7`=>!#
M@#PW/7790X!\-P$`=!%+C3PW2/_'Z/4H``!(A<!U`C'`2(7`0;X#&R``3`]%
M\$R)]^@)*0``2(T\10$```#H?"@``$F)QT$/M@:$P'0R2?_&3(G[9F8N#Q^$
M```````/MM"^^EH@`$B)WS'`Z"XH``!(@\,"00^V!DG_QH3`==],B;VH__[_
M13'VZS!(B=^^`@```.C&*```A<`/A`<!``!F9F9F9BX/'X0``````$G_QDF#
M_@4/A/P```!,BSU\3P``387_=.=.BRSU$%L@`$4QY$R)Z$BZ``````$```!F
M9F9F9F8N#Q^$```````/M@B%R709@_D]=!1(_\!)`=3K[&9F9BX/'X0`````
M`$F+'TB%VW282<'\($F#QPCK'F9F9F9F+@\?A```````28L?28/'"$B%VP^$
M</___TB)WTR)[DR)XNBB)P``A<!UWD*`/",]==="@'PC`0`/A$O___],`>-(
M_\-(B=](C;7`__[_Z'8H``"%P`^%+O___P^WA=C__O\E`/```#T`0```#X3T
M_O__/0"@```/A.G^___I!____TB)W^A?)P``28G%2(7`=49(C;7`__[_OS4<
M(`#H)B@``(7`#X2#`0``2(VUP/_^_[\-&R``Z`TH``"_#1L@`+X"````Z&XG
M``"_#1L@`.@4)P``28G%3(GOZ#DG``!(B<-,B[VH__[_3(G_Z"<G```!V`4$
M!```3&/@3(GGZ)4F``!)B<:^.QP@`+D*&R``0;@2'"``2(G'3(GJ38GY,<#H
M4B8``$R)][[``0``Z*4G``"#^/]U#NBK)P``@S@1#X4W`0``2(VUP/_^_TR)
M]^AS)P``A<`/A8<````/MYW8__[_B=@E`/```#T`0```=7)$B[W<__[_Z"HG
M``!!.<=U88'C_P$``('[P`$``'533(GGZ/\E``!)B<=,BRUU30``387M#X1B
M`0``N,(;(`!%,>1(N@`````!````9BX/'X0```````^V"(7)#X3@````@_D]
M#X37````2/_`20'4Z^1(BSV=30``2(N%L/_^_TB+$$4Q_[YX6B``3(GQ,<#H
M\28``$B+!3I-``!(.T70#X6U!```3(GX2('$.``!`%M!7$%=05Y!7UW##[>%
MV/_^_R4`\```/0!```!T"ST`H```#X5?_O__OS4<(`"^`@```.C>)0``A<`/
MA4C^__^_-1P@`.A\)0``28G%2(7`#X5?_O__Z2W^__](BQT$30``2(N%L/_^
M_TR+(.A5)@``1(L`13'_OE@;(`!(B=],B>),B?$QP.A*)@``Z53___])BUT`
M2(7;=%))P?P@28/%".L/9I!)BUT`28/%"$B%VW0YOL(;(`!(B=],B>+HXR0`
M`(7`==]"@#PC/7782HTT(TC_QDB+A;#__O](BSCHHN?__TF)Q$B%P'4*2(N%
ML/_^_TR+($R)Y^CX)```@_@$3(FEJ/_^_WP?2(G#B<!)C3P$2(/'_+[:&R``
MZ,4D``"%P`^$G0(``$BZ``````$```!,BRV\2P``387M='*XT!L@`#';#[8(
MA<ET#8/Y/70(2/_`2`'3Z^Q-BV4`387D=$Y(P?L@28/%".L69@\?A```````
M38ME`$F#Q0A-A>1T+K[0&R``3(GG2(G:Z!,D``"%P'7?08`\'#UUV$$/MD0<
M`8/X,'0(A<`/A74!``!(B[VH__[_,?8QP.@E)0``A<`/A%T!``!!B<6)QS'V
MN@(```#H'"4``$F)Q$C_R$F-G"3^_P``2(7`2`])V$B!XP``__\/B"H!``!(
M*=A)*<1)@\3%1(FML/_^_^LE2(V#``#__TF!Q```__](@?O__P``2(G#1(NM
ML/_^_P^.\@```$2)[TB)WC'2Z+4D``!(@_C_#X1E`@``N@@``0!$B>],C:W`
M__[_3(GNZ*0D``"#^/\/A%$"``!(8_A(C8VX__[_2`'Y3#GI#Y+!2(/_"'*+
MA,EUATB-C;C__O]-B>4/'T``2(L4.4@[%4U(``!T'DG_S4B-%#E(_\I(_\E(
MC;7`__[_2#GR<]KI3O___TACR$P!Z4B#P3)X64F)Q$B82HTT*$B#QBB+G;#_
M_O^)WS'2Z`TD``!(C;6Z__[_N@8```")W^@*)```2(/X!@^%P@$``+@`0T%#
M,X6Z__[_#[>-OO_^_X'Q2$4```G!#X0*`0``O]`;(`"^]!L@`.B1Y___Z`PB
M``"^Y!L@`+D*&R``0;D,&R``3(G_3(GR08G`,<#H_"$``$R)_[[``0``Z$\C
M``"#^/\/A1D!``"[`0```.A,(P``@S@1#X4&`0``Z+XA``!(QP0D#!L@`+X!
M'"``N0H;(`!,B?],B?)!B<!!B=DQP.BI(0``3(G_OL`!``#H_"(``/_#@_C_
M=+3IPP```(/[!$BZ``````$```!T$8/#^TACPT&`/`0O#X5-_?__2(N%L/_^
M_TB+6`A(A=L/A#G]__](B=_H]"$``$B#^`0/@AW]__](C3P#2(/'_+[?&R``
MZ,@A``"%P$P/1.-,B:6H__[_Z?G\__])8_1,`>Z+G;#__O^)WS'2Z+$B``!(
MC;7`__[_NB@```")W^BN(@``2(/X*'5JQH7H__[_`$R-A<#__O^^RUH@`+D*
M&R``0;D,&R``3(G_3(GR,<#HS2```$R)]^B%(@``O_`:(`!,B?[H*.;__TR)
M_^@0]?__Z3K[___HYB```+^M'"``,<#H.O3__[^Z'"``,<#H+O3__[\7'"``
M,<#H(O3__V:054B)Y4%7059!5%-,BR4.2```387D#X3$````2(G[N-`;(`!%
M,?9(N0`````!````#[80A=)T#8/Z/70(2/_`20'.Z^Q-BSPD387_#X2.````
M2<'^($F#Q`CK$@\?1```38L\)$F#Q`A-A?]T<K[0&R``3(G_3(GRZ%,@``"%
MP'7?0X`\-SUUV$B%VW120P^V1#<!A<!T2(/X,'1#@#L`=#Y(B=_HI^?__TF)
MQDB)Q[XO````Z+<@``!(C7@!2(7`20]$_N@G(```OA(<(`"Z!````$B)Q^CU
M'P``A<!T"5M!7$%>05]=PTB)WUM!7$%>05]=ZPMF9BX/'X0``````%5(B>5!
M5T%6055!5%-(@>SH````2(L%-4<``$B)1=!(A?\/A`,!``!(B?N`/P`/A/<`
M``!(B=_H%"$``$B%P`^$Y@```$F)QDB)Q^@0(0``2(7`#X3Q````28G$3(V]
M\/[__^LO9F8N#Q^$``````!,B>_H^"```$R)[^C`(```3(GWZ-@@``!)B<1(
MA<`/A+8```!)@\08O@T;(`!,B>?H:Q\``(7`=->^QQL@`$R)Y^A:'P``A<!T
MQDB)W^A>'P``28G%3(GGZ%,?``!$`>B#P`)(8_CHQ1X``$F)Q;[1&B``2(G'
M2(G:3(GA,<#HC1X``$R)[TR)_N@R'P``@_C_#X1I____#[>%"/___R4`\```
M/0!````/A5+___],B>_HVO[__^E-____2(L%'D8``$@[1=!U0$B!Q.@```!;
M05Q!74%>05]=PTR)]^@N(```2(L%]T4``$@[1=!U&4B)WTB!Q.@```!;05Q!
M74%>05]=Z1@@``#H0QX```\?`%5(B>5!5T%6055!5%-(@>P8!```2(L%M44`
M`$B)1=!)O``````!````2(L%4#,``&1(BPPE`````$R-+`%(BP0!#[:(L```
M`(B(L0```$R+/4M%``!-A?]T?;@E'"``,=MF9F9F9F8N#Q^$```````/M@B%
MR70-@_D]=`A(_\!,`>/K[$V+-TV%]G1+2,'[($F#QPCK%F8N#Q^$``````!-
MBS=)@\<(387V="N^)1P@`$R)]TB)VNB4'0``A<!UX$&`/!X]==E!@'P>`3%U
M"$&`?!X"`'0%Z/3E__])BWT`OJ@;(`"Z`0```+D#````Z"P?``!(A<!T*4F+
M?0!(BT@02(LQNIH;(`!(B</H'Q\``$B+0Q!(BS#V1@Y`#X5A`@``28M]`+Y<
M'"``N@$```"Y`P```.CF'@``2(7`#X0L`0``2(G#3(FMR/O__TR++4Q$``!-
MA>T/A(D```"X<1P@`$4Q]F9F+@\?A```````#[8(A<ET#8/Y/70(2/_`30'F
MZ^Q-BWT`387_=%E)P?X@28/%".L69@\?A```````38M]`$F#Q0A-A?]T.;YQ
M'"``3(G_3(GRZ),<``"%P'7?0X`\-SUUV$N-%#=(_\),BZW(^___28M]`$B+
M0Q!(BS#IA````$B+0Q!(BQA(BP6\0P``3(LP2(VUT/O__[]>'"``NO\#``#H
M`QP``(7`3(NMR/O__WY(08T,!/_)@+P-T/O__P!U!/_(=#1!B<=(C;W0^___
MOB\```!,B?KH_1T``$B%P'0828M]`$B-E=#[__](B=Y,B?GH\AT``.L/28M]
M`$B)WDR)\NC!'0``28M=`+Y$'"``2(G?N@$```#HVQT``+K*&R``2(G?2(G&
MZ)L=``!)BT4`QH"Q`````$R+/?E"``!-A?]T>[CP&B``,=MF9F9F+@\?A```
M````#[8(A<ET#8/Y/70(2/_`3`'CZ^Q-BS=-A?9T2TC!^R!)@\<(ZQ9F+@\?
MA```````38LW28/'"$V%]G0KOO`:(`!,B?=(B=KH1!L``(7`=>!!@#P>/779
M28T\'DC_QTB)/9-"``#K)DC'!89"````````2(L]=T(``.@2\/__2(G'2(D%
M<$(``$B%P'1)OL`!``#H"1P``(U(`8/Y`G(%@_@1=3Y(BP5E0@``2#M%T'4@
M2('$&`0``%M!7$%=05Y!7UW#28M]`.CD'```Z9']___HJAH``+\;&R``,<#H
MWAP``$B+#0="``!(BS%(BQ4%0@``OY`:(`")P3'`Z+\<``!F9F9F9F8N#Q^$
M``````!52(GE05=!5D%505132(/L*$B+!>A!``!(B470B7W,2(EUP$B)5;A(
MC7W,2(UUP$B-5;CHB!P``+]`LB``OE"R(`"Z4+(@`.BD'```@#WU00```'02
M9$B+!"4`````2`,%2R\``.L\Z)0<``!(B05]00``2(7`#X0<`P``2(G'Z(P<
M``!(BPTE+P``9$B+%"4`````2(T$"DB+#`K&@5\)````2(L(@(D2!````DB+
M`("($@0```%(8T7,C5@#2(T\Q2````#H51P``$B)!0Y!``!(BW7`2(L.2(D(
M2,=`""(<(`!(BPW5/@``2(E($$C'0!A9'"``BTW,N@0```"#^0(/C.P```"_
M`0```(/Y!W)828G`22GP28/`&$F#^"!R2$R-0?]-B<%)@^'\28UY`4F-401%
M,=(/'X0``````$(/$$36"$(/$$S6&$(/$430($(/$4S0,$F#P@1-.=%UWTTY
MR`^$B````$&)R4$I^4F)^$&#X0-T&@\?@`````!.BQ3&3(D4T$C_PDG_P$G_
MR77M2"G/2(/__'=62HTTQDB#QAA,*<%,C03028/`&#'_9F9F9F9F+@\?A```
M````3(M,_NA-B4SXZ$R+3/[P38E,^/!,BTS^^$V)3/CX3(L,_DV)#/A(@\<$
M2#GY==%(`?J)TDC'!-``````2(L][3\``+X@F2``B=I(B<%%,<#H&QL``(7`
M=0Q(BSW0/P``Z!L;``!(BSW$/P``Z!\;``")1;1,BRV5/P``387M#X2P````
MN,8<(`!(N@`````!````13'_9BX/'X0```````^V"(7)=`V#^3UT"$C_P$D!
MU^OL38MU`$V%]G0_2<'_($F-70A-B?3K$F8/'T0``$R+(TB#PPA-A>1T(+[&
M'"``3(GG3(GZZ-07``"%P'7@0X`\/#UUV>FG````2(L])3\``$B%_W4XN/`:
M(`!%,?](N@`````!````9@\?1```#[8(A<ET((/Y/70;2/_`20'7Z^Q(BSWM
M/@``2(7_=%CHJ_;__^M<387V=$Q)P?\@28/%".L79BX/'X0``````$V+=0!)
M@\4(387V="N^\!H@`$R)]TR)^NA#%P``A<!UWT.`/#X]==A+C3P^2/_'2(D]
MDCX``.NH2,<%A3X```````!(BSV&/@``Z/$9``#H_!D``$B+!84^``!(.T70
M=1*+1;1(@\0H6T%<05U!7D%?7</HV!8``+\!````Z*X7``!F9F9F9BX/'X0`
M`````%5(B>5!5E-(BQWR*P``9$R+-"4`````28L\'KX\&R``NG"O(`"Y`%L@
M`.@Q%@``28L\'K[7&B``NJ"1(`"Y#!L@`$&X#!L@`$4QR5M!7EWI?!D``,S,
MS,S,S,S,S,S,S%5(B>6_@````.@R%@``2,<``2-%9[G^W+J82(V1B\X25TB)
M4`A(B4@02,=`&'94,A!(@<'R!!@K2(E((,=`>``````/5\`/$4`H7<,/'T``
M54B)Y4%7059!54%44U!!B=9(B?M(BT<H2&/*C13(2,'I'4@YPDB)5RA($4\P
M28GW2&-'>$B%P'1$N4`````IP40Y\4$/3<Y(C3P#2(/'.$QCX4R)_DR)XNBC
M%0``BT-X1`'@B4-X@_A`#X5_````30'G12GF2(G?Z(,```!!@_Y`?%),C6,X
M9@\?A```````00\0!T$/$$\000\05R!!#Q!?,$$/$5PD,$$/$50D($$/$4PD
M$$$/$00D28/'0$6-;L!(B=_H-@```$&#_G]%B>YWO>L#18GU2(U[.$UC]4R)
M_DR)\N@6%0``1(ES>$B#Q`A;05Q!74%>05]=PP\?`%5(B>5!5T%6055!5%-(
M@>RX`@``2(L%A3P``$B)1=!(BT<XB<$/R4B)C5#]__](B<%(P>D@P>$82(G"
M2,'J&('B``#_`$B)QDC![BB!Y@#_``!(P>@X2`GP2`G02`G(2(F%6/W__TB+
M1T")P0_)2(F-8/W__TB)P4C!Z2#!X1A(B<)(P>H8@>(``/\`2(G&2,'N*('F
M`/\``$C!Z#A("?!("=!("<A(B85H_?__2(M'2(G!#\E(B8UP_?__2(G!2,'I
M(,'A&$B)PDC!ZAB!X@``_P!(B<9(P>XH@>8`_P``2,'H.$@)\$@)T$@)R$B)
MA7C]__](BT=0B<$/R4B)C8#]__](B<%(P>D@P>$82(G"2,'J&('B``#_`$B)
MQDC![BB!Y@#_``!(P>@X2`GP2`G02`G(2(F%B/W__TB+1UB)P0_)2(F-D/W_
M_TB)P4C!Z2#!X1A(B<)(P>H8@>(``/\`2(G&2,'N*('F`/\``$C!Z#A("?!(
M"=!("<A(B868_?__2(M'8(G!#\E(B8V@_?__2(G!2,'I(,'A&$B)PDC!ZAB!
MX@``_P!(B<9(P>XH@>8`_P``2,'H.$@)\$@)T$@)R$B)A:C]__](BT=HB<$/
MR4B)C;#]__](B<%(P>D@P>$82(G"2,'J&('B``#_`$B)QDC![BB!Y@#_``!(
MP>@X2`GP2`G02`G(2(F%N/W__TB+1W")P0_)2(F-P/W__TB)P4C!Z2#!X1A(
MB<)(P>H8@>(``/\`2(G&2,'N*('F`/\``$C!Z#A("?!("=!("<A(B87(_?__
MN!`````/'T``2(N,Q1#]__](,XS%./W__T@SC,7@_/__2#.,Q=#\__^-%`E(
MP>D?"=%(B8S%4/W__TC_P$B#^%!UQDR+'TR+3PB+=Q"+3QB+5R")E4#]__]-
MB=I$B<C!X!Y-B<A-B<],B8TH_?__2<'H`D$)P$2)PS'S1"';18G>38G9BT7(
M1`'82(F%,/W__T2)V,'@!4G!ZAM!"<*)\#'(1"'X,<A!B<N)C43]__^+C5#]
M__]!`=)!`<)&C20108'$F7F"6D2)X,'@!42)X<'I&S'SB;5(_?__1`';`YU8
M_?__`<M$C10808'"F7F"6D'!YAY)P>D"10GQ1(G0P>`%1(G)1#'!1"'A1#'!
MBY5@_?__`?(!RD2)T<'I&P'*1(T<$$&!PYEY@EI!P<0>1(G8P>`%1(GA1#')
M1"'11#')1`.%:/W__T$!R$2)V<'I&T$!R$$!P$&!P)EY@EI!P<(>1(G`P>`%
M1(G11#'A1"'91#'A1`.-</W__T$!R42)P<'I&T$!R4'!PQY&C30(08'&F7F"
M6D2)\,'@!42)V40QT40AP40#I7C]__]$,=%!`<Q$B?'!Z1M!`<Q"C1P@@<.9
M>8):0<'`'HG8P>`%1(G!1#'91"'Q1#'91`.5@/W__T$!RHG9P>D;00'*00'"
M08'"F7F"6D'!QAY$B=#!X`5$B?%$,<$AV40QP40#G8C]__]!`<M$B='!Z1M!
M`<M&C0P808'!F7F"6L'#'D2)R,'@!8G91#'Q1"'11#'Q1`.%D/W__T$!R$2)
MR<'I&T$!R$'!PAY&C20`08'$F7F"6D2)X,'@!42)T3'91"')1`.UF/W__S'9
M00'.1(GAP>D;00'.1HT<,$&!PYEY@EI!P<$>1(G8P>`%1(G)1#'11"'A1#'1
M`YV@_?__`<M$B=G!Z1L!RP'#@<.9>8):0<'$'HG8P>`%1(GA1#')1"'91#')
M1`.5J/W__T$!RHG9P>D;00'*1HT$$$&!P)EY@EI!P<,>1(G`P>`%1(G91#'A
M(=E$,>%$`XVP_?__00')1(G!P>D;00')P<,>1HTT"$&!QIEY@EI$B?#!X`6)
MV40QV40AP40#I;C]__]$,=E!`<Q$B?'!Z1M!`<Q&C0P@08'!F7F"6D'!P!Y$
MB<C!X`5$B<$QV40A\3'91`.=P/W__T$!RT2)R<'I&T$!RT:-%!A!@<*9>8):
M0<'&'D2)T,'@!42)\40QP40AR40QP0.=R/W__P'+1(G1P>D;`<M$C1P808'#
MF7F"6D'!P1Y$B=C!X`5$B<E$,?%$(=%$,?%$`X70_?__00'(1(G9P>D;00'(
M0<'"'D$!P$&!P)EY@EI$B<#!X`5$B=%$,<E$(=E$`[78_?__1#')00'.1(G!
MP>D;00'.0HT<,('#F7F"6D'!PQZ)V,'@!42)V40QT40AP40QT40#C>#]__]!
M`<F)V<'I&T$!R4$!P4&!P9EY@EI!P<`>1(G(P>`%1(G!1#'9(=E$,=E$`Y7H
M_?__00'*1(G)P>D;00'*00'"08'"F7F"6L'#'D2)T,'@!8G91#'!1`.=\/W_
M_T0QR4$!RT2)T<'I&T$!RT$!PT&!PZ'KV6Y!P<$>1(G8P>`%1(G),=E$,=%$
M`X7X_?__00'(1(G9P>D;00'(00'`08'`H>O9;D'!PAY$B<#!X`5$B=%$,<D#
MG0#^__]$,=D!RT2)P<'I&P'+`<.!PZ'KV6Y!P<,>B=C!X`5$B=E$,=%$,<%$
M`XT(_O__00')B=G!Z1M!`<E!`<%!@<&AZ]EN0<'`'D2)R,'@!42)P40QV40#
ME1#^__\QV4$!RD2)R<'I&T$!RD$!PD&!PJ'KV6[!PQY$B=#!X`6)V40QP40Q
MR40#G1C^__]!`<M$B='!Z1M!`<M!`<-!@<.AZ]EN0<'!'D2)V,'@!42)R3'9
M1`.%(/[__T0QT4$!R$2)V<'I&T$!R$$!P$&!P*'KV6Y!P<(>1(G`P>`%1(G1
M1#')1#'9`YTH_O__`<M$B<'!Z1L!RP'#@<.AZ]EN0<'#'HG8P>`%1(G91#'1
M1`.-,/[__T0QP4$!R8G9P>D;00')00'!08'!H>O9;D'!P!Y$B<C!X`5$B<%$
M,=DQV40#E3C^__]!`<I$B<G!Z1M!`<I!`<)!@<*AZ]ENP<,>1(G0P>`%B=E$
M,<%$`YU`_O__1#')00'+1(G1P>D;00'+00'#08'#H>O9;D'!P1Y$B=C!X`5$
MB<DQV40QT40#A4C^__]!`<A$B=G!Z1M!`<A!`<!!@<"AZ]EN0<'"'D2)P,'@
M!42)T40QR0.=4/[__T0QV0'+1(G!P>D;`<L!PX'#H>O9;D'!PQZ)V,'@!42)
MV40QT40QP40#C5C^__]!`<F)V<'I&T$!R4$!P4&!P:'KV6Y!P<`>1(G(P>`%
M1(G!1#'91`.58/[__S'900'*1(G)P>D;00'*1HTD$$&!Q*'KV6[!PQY$B>#!
MX`6)V40QP40QR40#G6C^__]!`<M$B>'!Z1M!`<M&C10808'"H>O9;D'!P1Y$
MB=#!X`5$B<DQV40#A7#^__]$,>%!`<A$B='!Z1M!`<A&C30`08'&H>O9;D'!
MQ!Y$B?#!X`5$B>%$,<E$,=$#G7C^__\!RT2)\<'I&P'+1(TL&$&!Q:'KV6Y!
MP<(>1(GHP>`%1(G11#'A1`.-@/[__T0Q\4$!R42)Z<'I&T$!R4$!P4&!P:'K
MV6Y!P<8>1(G(P>`%1(GQ1#'11#'I1`.EB/[__T$!S$2)R<'I&T$!S$B)O3C]
M__]"C3P@@<>AZ]EN0<'%'D6)[$4)]$4AS$'!P1Y$B<E$">DA^4&)_XG^P<<>
M08G[10G+B?I$(<I!N-R\&X^+G:C^__]$`<-$`<M$B<A$(>A$BXV@_O__10'!
M10'I12'U10GE1(NED/[__T4!Q$4!U$4![,'N&T$!]$'!YP5%`?P)R(NUF/[_
M_T0!QD0!]@'&1(G@P>@;`<9$B>#!X`4!QD4AXT0)VD$!T8GPP>@;00'!B?#!
MX`5!P<0>1(GA"?DA\<'&'D$!P8GR1`GB1"'*18G-18G/0<'!'D2)R`GP18G+
M02'S1(NUP/[__T4!QD$!]D0AYD2+E;C^__]%`<)%`>)!(?Q!"<Q$`>-!P>\;
M1`'[0<'E!40!ZPG61(NML/[__T4!Q4$!_4$!]8G9P>D;00'-B=G!X05!`<TA
MV$$)PT4!VD2)Z,'H&T$!PD2)Z,'@!4$!PL'#'HG:1`G*1"'J0<'%'D2)[@G>
M1"'61(G718G70<'"'D2)T$0)Z$2)T40AZ42+I=C^__]%`<1%`>Q!(=U$BYW0
M_O__10'#00';1"'+"=-!`=Y!P>\;10'^P><%00'^00GUBYW(_O__1`'#1`'+
M1`'K1(GRP>H;`=-$B?+!X@4!TT0A\`G!00'+B=C!Z!M!`<.)V,'@!4'!QAY$
MB?)$"=(AVL'#'D$!PXG>1`GV1"'>1(G?18G90<'#'D2)V`G81(G9(=E$BZWP
M_O__10'%00'=08G?12'WBYWH_O__1`'#1`'S12'600G610'T0<'I&T4!S,'G
M!4$!_$$)]T2+M>#^__]%`<9%`=9%`?Y$B>+!ZAM!`=9$B>+!X@5!`=9$(>`)
MP0'+1(GPP>@;`<-$B?#!X`4!PT'!Q!Y$B>)$"=I$(?)!P<8>1(GV1`GF(=Z)
MWT&)VL'#'HG81`GPB=E$(?%$BXT(____10'!10'Q18GW12'G1(NU`/___T4!
MQD4!YD4AW$$)U$4!Y4'!ZAM%`=7!YP5!`?U!"?=$BZ7X_O__10'$10'<10'\
M1(GJP>H;00'41(GJP>(%00'41"'H"<%!`<Y$B>#!Z!M!`<9$B>#!X`5!P<4>
M1(GJ"=I$(>)!P<0>00'&1(GF1`GN1"'V1(FU3/W__T6)]T'!QAY$B?=$">=$
MB?%$(>%$BY4@____10'"10'B1(G@1"'H1(N=&/___T4!PT4!ZT$AW4$)U44!
MZ4'![QM%`?F+E4S]___!X@5!`=$)\$2+I1#___]%`<1!`=Q!`<1$B<C!Z!M!
M`<1$B<C!X`5!`<1$(<\)^4$!RT2)X,'H&T$!PT2)X,'@!4$!PT'!P1Y$B<A$
M"?!$(>!$B<E$(?$)P4$!RD2)V,'H&T$!PD2)V,'@!4'!Q!Y!`<)$B>!$"<A$
M(=A$B>%$(<E$`X4H____"<%%`?!$B=#!X`5!`<A$B='!Z1M!`<A!`<!!P<,>
M1(G`P>`%1(G91#'A1#'11`.-,/___T$!R42)P<'I&T$!R4'!PAY"C1P(@</6
MP6+*B=C!X`5$B=%$,=E$,<%$`Z4X____00',B=G!Z1M!`<Q&C0P@08'!UL%B
MRD'!P!Y$B<C!X`5$B<%$,=$QV40#G4#___]!`<M$B<G!Z1M!`<O!PQY!`<-!
M@</6P6+*1(G8P>`%B=E$,<%$,<E$`Y5(____00'*1(G9P>D;00'*00'"08'"
MUL%BRD'!P1Y$B=#!X`5$B<DQV40QV40#A5#___]!`<A$B='!Z1M!`<A!P<,>
M1HTT`$&!QM;!8LI$B?#!X`5$B=E$,<E$,=$#G5C___\!RT2)\<'I&P'+1(T$
M&$&!P-;!8LI!P<(>1(G`P>`%1(G11#'91#'Q1`.-8/___T$!R42)P<'I&T$!
MR4'!QAY"C1P(@</6P6+*B=C!X`5$B?%$,=%$,<%$`YUH____00'+B=G!Z1M!
M`<M&C0P808'!UL%BRD'!P!Y$B<C!X`5$B<%$,?$QV40#E7#___]!`<I$B<G!
MZ1M!`<K!PQY&C20008'$UL%BRD2)X,'@!8G91#'!1#')1`.U>/___T$!SD2)
MX<'I&T$!SD:-%#!!@<+6P6+*0<'!'D2)T,'@!42)R3'91#'A1`-%@$$!R$2)
MT<'I&T$!R$'!Q!Y!`<!!@<#6P6+*1(G`P>`%1(GA1#')1#'1`UV(`<M$B<'!
MZ1L!RT2-'!A!@</6P6+*0<'"'D2)V,'@!42)T40QX40QP40#39!!`<E$B=G!
MZ1M!`<E!P<`>0HT<"('#UL%BRHG8P>`%1(G!1#'11#'91`-EF$$!S(G9P>D;
M00',1HT,($&!P=;!8LI!P<,>1(G(P>`%1(G91#'!,=E$`U6@00'*1(G)P>D;
M00'*P<,>1HTT$$&!QM;!8LI$B?#!X`6)V40QV40QR40#1:A!`<A$B?'!Z1M!
M`<A!`<!!@<#6P6+*0<'!'D2)P,'@!42)R3'91#'Q1`-=L$$!RT2)P<'I&T$!
MRT'!QAY&C10808'"UL%BRD2)T,'@!42)\40QR40QP0-=N`'+1(G1P>D;`<M$
MC1P808'#UL%BRD'!P!Y$B=C!X`5$B<%$,?%$,=%$`TW`00')1(G9P>D;00')
M08T,`40!R`76P6+*0<'"'DB+M3#]__]$`?9$B=)$,<)$,=H!UHG"P>@;`<;!
MX@6-!#(%UL%BRDB+E3C]__](B0)(BX4H_?__`<@%UL%BRDB)0@A$B=A!P>L"
M1`.=2/W__\'@'D$!PTR)6A!$`Y5$_?__3(E2&$0#A4#]__],B4(@2(L%'"H`
M`$@[1=!U$DB!Q+@"``!;05Q!74%>05]=P^AO`@``9F9F9F9F+@\?A```````
M54B)Y4%7059!54%44U!(B?-)B?Y(BU8H3(MN,$F)U,'J`X/B/\9$%CB`2(T\
M%DB#QSF#^CAR,4R->SB#\C\Q]N@[!0``2(G?Z`/M__\/5\!!#Q%'($$/$4<0
M00\1!TG'1S``````ZQ&X-P```"G0,?9(B<+H!P4``$R)Z8G(P>@8B$-PB<C!
MZ!"(0W&(:W*(2W-,B>&)R,'H&(A#=(G(P>@0B$-UB&MVB$MW2(G?Z)WL__\/
MMD,#08@&#[9#`D&(1@$/MD,!08A&`@^V`T&(1@,/MD,+08A&!`^V0PI!B$8%
M#[9#"4&(1@8/MD,(08A&!P^V0Q-!B$8(#[9#$D&(1@D/MD,108A&"@^V0Q!!
MB$8+#[9#&T&(1@P/MD,:08A&#0^V0QE!B$8.#[9#&$&(1@\/MD,C08A&$`^V
M0R)!B$81#[9#(4&(1A(/MD,@08A&$TB)WTB#Q`A;05Q!74%>05]=Z7D"``#,
MS,S,S,S,S,Q52(GE4U!(C1T3%```#Q\`2(L#2(U(`4B#^0)R"/_02(/#^.OK
M2(/$"%M=PU5(B>7HR____UW#`%5(B>7HC\'__UW#`````````````````/\U
M"B8``/\E#"8```\?0`#_)0HF``!H`````.G@_____R4")@``:`$```#IT/__
M__\E^B4``&@"````Z<#_____)?(E``!H`P```.FP_____R7J)0``:`0```#I
MH/____\EXB4``&@%````Z9#_____)=HE``!H!@```.F`_____R72)0``:`<`
M``#I</____\ERB4``&@(````Z6#_____)<(E``!H"0```.E0_____R6Z)0``
M:`H```#I0/____\ELB4``&@+````Z3#_____):HE``!H#````.D@_____R6B
M)0``:`T```#I$/____\EFB4``&@.````Z0#_____)9(E``!H#P```.GP_O__
M_R6*)0``:!````#IX/[___\E@B4``&@1````Z=#^____)7HE``!H$@```.G`
M_O___R5R)0``:!,```#IL/[___\E:B4``&@4````Z:#^____)6(E``!H%0``
M`.F0_O___R5:)0``:!8```#I@/[___\E4B4``&@7````Z7#^____)4HE``!H
M&````.E@_O___R5")0``:!D```#I4/[___\E.B4``&@:````Z4#^____)3(E
M``!H&P```.DP_O___R4J)0``:!P```#I(/[___\E(B4``&@=````Z1#^____
M)1HE``!H'@```.D`_O___R42)0``:!\```#I\/W___\E"B4``&@@````Z>#]
M____)0(E``!H(0```.G0_?___R7Z)```:"(```#IP/W___\E\B0``&@C````
MZ;#]____)>HD``!H)````.F@_?___R7B)```:"4```#ID/W___\EVB0``&@F
M````Z8#]____)=(D``!H)P```.EP_?___R7*)```:"@```#I8/W___\EPB0`
M`&@I````Z5#]____);HD``!H*@```.E`_?___R6R)```:"L```#I,/W___\E
MJB0``&@L````Z2#]____):(D``!H+0```.D0_?___R6:)```:"X```#I`/W_
M__\EDB0``&@O````Z?#\____)8HD``!H,````.G@_/___R6")```:#$```#I
MT/S___\E>B0``&@R````Z<#\____)7(D``!H,P```.FP_/___R5J)```:#0`
M``#IH/S___\E8B0``&@U````Z9#\____)5HD``!H-@```.F`_/___R52)```
M:#<```#I</S___\E2B0``&@X````Z6#\____)4(D``!H.0```.E0_/___R4Z
M)```:#H```#I0/S___\E,B0``&@[````Z3#\_____________P``````````
M__________\`````````````````````\'`@```````=`````````/8#````
M`````0`````````:!`````````$`````````*@0````````!`````````#4$
M`````````0`````````_!`````````$`````````300````````!````````
M`,4#`````````0````````#:`P```````!4````````````````````'````
M`````(@4(```````"`````````!@``````````D`````````&``````````7
M`````````.@4(````````@````````"@!0````````,`````````2-4@````
M```4``````````<`````````!@`````````(`R````````L`````````&```
M```````%`````````"P0(```````"@````````!:!````````/7^_V\`````
M>`P@```````$`````````%P-(```````&0`````````XPR```````!L`````
M````"``````````,`````````!RO(```````#0`````````HKR```````/#_
M_V\`````8`L@``````#^__]O`````!0,(```````____;P`````"````````
M``````````````````````````````````P;(```````YQP@```````*4$%2
M+G!M"@``````````0,,@````````````````````````````5J\@``````!F
MKR```````':O(```````AJ\@``````"6KR```````*:O(```````MJ\@````
M``#&KR```````-:O(```````YJ\@``````#VKR````````:P(```````%K`@
M```````FL"```````#:P(```````1K`@``````!6L"```````&:P(```````
M=K`@``````"&L"```````):P(```````IK`@``````"VL"```````,:P(```
M````UK`@``````#FL"```````/:P(```````!K$@```````6L2```````":Q
M(```````-K$@``````!&L2```````%:Q(```````9K$@``````!VL2``````
M`(:Q(```````EK$@``````"FL2```````+:Q(```````QK$@``````#6L2``
M`````.:Q(```````]K$@```````&LB```````!:R(```````)K(@```````V
MLB```````$:R(```````5K(@``````!FLB```````':R(```````AK(@````
M``"6LB```````*:R(```````MK(@``````#&LB```````-:R(```````YK(@
M``````#VLB````````:S(````````$9R965"4T0@8VQA;F<@=F5R<VEO;B`Q
M."XQ+C8@*&AT='!S.B\O9VET:'5B+F-O;2]L;'9M+VQL=FTM<')O:F5C="YG
M:70@;&QV;6]R9RTQ."XQ+C8M,"UG,3$Q.&,R93`U938W*0!,:6YK97(Z($Q,
M1"`Q."XQ+C8@*$9R965"4T0@;&QV;6]R9RTQ."XQ+C8M,"UG,3$Q.&,R93`U
M938W+3$T,#`P,#<I```N:6YT97)P`"YN;W1E+G1A9P`N9'EN<WEM`"YG;G4N
M=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N9VYU+FAA<V@`+FAA<V@`+F1Y;G-T
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N
M96A?9G)A;64`+G1E>'0`+FEN:70`+F9I;FD`+G!L=``N8W1O<G,`+F1T;W)S
M`"YJ8W(`+FEN:71?87)R87D`+F1Y;F%M:6,`+F=O=``N<F5L<F]?<&%D9&EN
M9P`N9&%T80`N9V]T+G!L=``N8G-S`"YC;VUM96YT`"YS:'-T<G1A8@``````
M````````````````````````````````````````````````````````````
M``````````````````````````````$````!`````@````````"H`B``````
M`*@"````````%0````````````````````$````````````````````)````
M!P````(`````````P`(@``````#``@```````$@````````````````````$
M````````````````````$P````L````"``````````@#(```````"`,`````
M``!8"`````````@````!````"``````````8`````````!L```#___]O`@``
M``````!@"R```````&`+````````L@`````````#``````````(`````````
M`@`````````H````_O__;P(`````````%`P@```````4#````````&``````
M````"`````(````$````````````````````-P```/;__V\"`````````'@,
M(```````>`P```````#D``````````,`````````"```````````````````
M`$$````%`````@````````!<#2```````%P-````````T`(````````#````
M``````0`````````!`````````!'`````P````(`````````+!`@```````L
M$````````%H$```````````````````!````````````````````3P````0`
M```"`````````(@4(```````B!0```````!@``````````,`````````"```
M```````8`````````%D````$````0@````````#H%"```````.@4````````
MH`4````````#````&@````@`````````&`````````!C`````0```#(`````
M````D!H@``````"0&@```````+=````````````````````0````````````
M````````:P````$````"`````````$A;(```````2%L```````#<````````
M````````````!````````````````````'D````!`````@`````````H7"``
M`````"A<````````5`0```````````````````@```````````````````"#
M`````0````8`````````@'`@``````"`8````````)P^````````````````
M```0````````````````````B0````$````&`````````!RO(```````')\`
M```````+````````````````````!````````````````````(\````!````
M!@`````````HKR```````"B?````````"P````````````````````0`````
M``````````````"5`````0````8`````````0*\@``````!`GP```````-`#
M```````````````````0````````````````````F@````$````#````````
M`!##(```````$*,````````0````````````````````"```````````````
M`````*$````!`````P`````````@PR```````""C````````$```````````
M``````````@```````````````````"H`````0````,`````````,,,@````
M```PHP````````@````````````````````(````````````````````K0``
M``X````#`````````#C#(```````.*,````````(````````````````````
M"````````````````````+D````&`````P````````!`PR```````$"C````
M````X`$````````(``````````@`````````$`````````#"`````0````,`
M````````(,4@```````@I0````````@````````````````````(````````
M````````````QP````@````#`````````"C%(```````**4```````#8"@``
M`````````````````0```````````````````-8````!`````P`````````H
MU2```````"BE````````&0````````````````````@`````````````````
M``#<`````0````,`````````2-4@``````!(I0```````/@!````````````
M```````(````````````````````Y0````@````#`````````$#7(```````
M0*<```````!Y````````````````````$````````````````````.H````!
M````,````````````````````$"G````````K`````````````````````$`
M`````````0````````#S`````P````````````````````````#LIP``````
A`/T````````````````````!````````````````````
